@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2012 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2013 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -33,9 +33,12 @@ double end_timer(void);
 char *ether_ntoa_long(const struct ether_addr *addr);
 char *get_name_by_macaddr(struct ether_addr *mac_addr, int read_opt);
 char *get_name_by_macstr(char *mac_str, int read_opt);
+int file_exists(const char *fpath);
 int read_file(char *dir, char *path, int read_opt,
-	      float orig_timeout, float watch_interval);
+	      float orig_timeout, float watch_interval, size_t header_lines);
 int write_file(char *dir, char *fname, char *arg1, char *arg2);
+struct ether_addr *translate_mac(char *mesh_iface, struct ether_addr *mac);
+struct ether_addr *resolve_mac(const char *asc);
 
 extern char *line_ptr;
 
@@ -48,4 +51,6 @@ enum {
 	USE_READ_BUFF = 0x10,
 	SILENCE_ERRORS = 0x20,
 	NO_OLD_ORIGS = 0x40,
+	COMPAT_FILTER = 0x80,
+	SKIP_HEADER = 0x100,
 };
