@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007-2012 B.A.T.M.A.N. contributors:
+ * Copyright (C) 2007-2013 B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>, Marek Lindner <lindner_marek@yahoo.de>
  *
@@ -44,13 +44,14 @@ char is_aborted = 0;
 
 void ping_usage(void)
 {
-	printf("Usage: batctl ping [options] mac|bat-host \n");
-	printf("options:\n");
-	printf(" \t -c ping packet count \n");
-	printf(" \t -h print this help\n");
-	printf(" \t -i interval in seconds\n");
-	printf(" \t -t timeout in seconds\n");
-	printf(" \t -R record route\n");
+	fprintf(stderr, "Usage: batctl [options] ping [parameters] mac|bat-host|host_name|IPv4_address \n");
+	fprintf(stderr, "parameters:\n");
+	fprintf(stderr, " \t -c ping packet count \n");
+	fprintf(stderr, " \t -h print this help\n");
+	fprintf(stderr, " \t -i interval in seconds\n");
+	fprintf(stderr, " \t -t timeout in seconds\n");
+	fprintf(stderr, " \t -R record route\n");
+	fprintf(stderr, " \t -T don't try to translate mac to originator address\n");
 }
 
 void sig_handler(int sig)
@@ -67,7 +68,7 @@ void sig_handler(int sig)
 
 int ping(char *mesh_iface, int argc, char **argv)
 {
-	struct icmp_packet_rr icmp_packet_out, icmp_packet_in;
+	struct batadv_icmp_packet_rr icmp_packet_out, icmp_packet_in;
 	struct timeval tv;
 	struct ether_addr *dst_mac = NULL, *rr_mac = NULL;
 	struct bat_host *bat_host, *rr_host;
@@ -79,12 +80,13 @@ int ping(char *mesh_iface, int argc, char **argv)
 	char *dst_string, *mac_string, *rr_string;
 	double time_delta;
 	float min = 0.0, max = 0.0, avg = 0.0, mdev = 0.0;
-	uint8_t last_rr_cur = 0, last_rr[BAT_RR_LEN][ETH_ALEN];
+	uint8_t last_rr_cur = 0, last_rr[BATADV_RR_LEN][ETH_ALEN];
 	size_t packet_len;
 	char *debugfs_mnt;
 	char icmp_socket[MAX_PATH+1];
+	int disable_translate_mac = 0;
 
-	while ((optchar = getopt(argc, argv, "hc:i:t:R")) != -1) {
+	while ((optchar = getopt(argc, argv, "hc:i:t:RT")) != -1) {
 		switch (optchar) {
 		case 'c':
 			loop_count = strtol(optarg, NULL , 10);
@@ -111,6 +113,10 @@ int ping(char *mesh_iface, int argc, char **argv)
 			rr = 1;
 			found_args++;
 			break;
+		case 'T':
+			disable_translate_mac = 1;
+			found_args += 1;
+			break;
 		default:
 			ping_usage();
 			return EXIT_FAILURE;
@@ -118,7 +124,7 @@ int ping(char *mesh_iface, int argc, char **argv)
 	}
 
 	if (argc <= found_args) {
-		printf("Error - target mac address or bat-host name not specified\n");
+		fprintf(stderr, "Error - target mac address or bat-host name not specified\n");
 		ping_usage();
 		return EXIT_FAILURE;
 	}
@@ -131,21 +137,24 @@ int ping(char *mesh_iface, int argc, char **argv)
 		dst_mac = &bat_host->mac_addr;
 
 	if (!dst_mac) {
-		dst_mac = ether_aton(dst_string);
+		dst_mac = resolve_mac(dst_string);
 
 		if (!dst_mac) {
-			printf("Error - the ping destination is not a mac address or bat-host name: %s\n", dst_string);
+			fprintf(stderr, "Error - mac address of the ping destination could not be resolved and is not a bat-host name: %s\n", dst_string);
 			goto out;
 		}
 	}
 
+	if (!disable_translate_mac)
+		dst_mac = translate_mac(mesh_iface, dst_mac);
+
 	mac_string = ether_ntoa_long(dst_mac);
 	signal(SIGINT, sig_handler);
 	signal(SIGTERM, sig_handler);
 
 	debugfs_mnt = debugfs_mount(NULL);
 	if (!debugfs_mnt) {
-		printf("Error - can't mount or find debugfs\n");
+		fprintf(stderr, "Error - can't mount or find debugfs\n");
 		goto out;
 	}
 
@@ -154,26 +163,28 @@ int ping(char *mesh_iface, int argc, char **argv)
 	ping_fd = open(icmp_socket, O_RDWR);
 
 	if (ping_fd < 0) {
-		printf("Error - can't open a connection to the batman adv kernel module via the socket '%s': %s\n",
+		fprintf(stderr, "Error - can't open a connection to the batman adv kernel module via the socket '%s': %s\n",
 				icmp_socket, strerror(errno));
 		printf("Check whether the module is loaded and active.\n");
 		goto out;
 	}
 
-	packet_len = sizeof(struct icmp_packet);
+	packet_len = sizeof(struct batadv_icmp_packet);
 
 	memcpy(&icmp_packet_out.dst, dst_mac, ETH_ALEN);
-	icmp_packet_out.header.packet_type = BAT_ICMP;
-	icmp_packet_out.header.version = COMPAT_VERSION;
-	icmp_packet_out.msg_type = ECHO_REQUEST;
+	icmp_packet_out.header.packet_type = BATADV_ICMP;
+	icmp_packet_out.header.version = BATADV_COMPAT_VERSION;
+	icmp_packet_out.msg_type = BATADV_ECHO_REQUEST;
 	icmp_packet_out.header.ttl = 50;
 	icmp_packet_out.seqno = 0;
 
 	if (rr) {
-		packet_len = sizeof(struct icmp_packet_rr);
+		packet_len = sizeof(struct batadv_icmp_packet_rr);
 		icmp_packet_out.rr_cur = 1;
-		memset(&icmp_packet_out.rr, 0, BAT_RR_LEN * ETH_ALEN);
-		memset(last_rr, 0, BAT_RR_LEN * ETH_ALEN);
+		memset(&icmp_packet_out.rr, 0, BATADV_RR_LEN * ETH_ALEN);
+		memset(last_rr, 0, BATADV_RR_LEN * ETH_ALEN);
+	} else {
+		((struct batadv_icmp_packet *)&icmp_packet_out)->reserved = 0;
 	}
 
 	printf("PING %s (%s) %zu(%zu) bytes of data\n", dst_string, mac_string,
@@ -192,7 +203,7 @@ int ping(char *mesh_iface, int argc, char **argv)
 		icmp_packet_out.seqno = htons(++seq_counter);
 
 		if (write(ping_fd, (char *)&icmp_packet_out, packet_len) < 0) {
-			printf("Error - can't write to batman adv kernel file '%s': %s\n", icmp_socket, strerror(errno));
+			fprintf(stderr, "Error - can't write to batman adv kernel file '%s': %s\n", icmp_socket, strerror(errno));
 			goto sleep;
 		}
 
@@ -220,7 +231,7 @@ read_packet:
 		read_len = read(ping_fd, (char *)&icmp_packet_in, packet_len);
 
 		if (read_len < 0) {
-			printf("Error - can't read from batman adv kernel file '%s': %s\n", icmp_socket, strerror(errno));
+			fprintf(stderr, "Error - can't read from batman adv kernel file '%s': %s\n", icmp_socket, strerror(errno));
 			goto sleep;
 		}
 
@@ -235,22 +246,22 @@ read_packet:
 			goto read_packet;
 
 		switch (icmp_packet_in.msg_type) {
-		case ECHO_REPLY:
+		case BATADV_ECHO_REPLY:
 			time_delta = end_timer();
 			printf("%zd bytes from %s icmp_seq=%hu ttl=%d time=%.2f ms",
 					read_len, dst_string, ntohs(icmp_packet_in.seqno),
 					icmp_packet_in.header.ttl, time_delta);
 
-			if (read_len == sizeof(struct icmp_packet_rr)) {
+			if (read_len == sizeof(struct batadv_icmp_packet_rr)) {
 				if (last_rr_cur == icmp_packet_in.rr_cur
-					&& !memcmp(last_rr, icmp_packet_in.rr, BAT_RR_LEN * ETH_ALEN)) {
+					&& !memcmp(last_rr, icmp_packet_in.rr, BATADV_RR_LEN * ETH_ALEN)) {
 
 					printf("\t(same route)");
 
 				} else {
 					printf("\nRR: ");
 
-					for (i = 0; i < BAT_RR_LEN
+					for (i = 0; i < BATADV_RR_LEN
 						&& i < icmp_packet_in.rr_cur; i++) {
 
 						rr_mac = (struct ether_addr *)&icmp_packet_in.rr[i];
@@ -266,7 +277,7 @@ read_packet:
 					}
 
 					last_rr_cur = icmp_packet_in.rr_cur;
-					memcpy(last_rr, icmp_packet_in.rr, BAT_RR_LEN * ETH_ALEN);
+					memcpy(last_rr, icmp_packet_in.rr, BATADV_RR_LEN * ETH_ALEN);
 				}
 			}
 
@@ -280,15 +291,15 @@ read_packet:
 			mdev += time_delta * time_delta;
 			packets_in++;
 			break;
-		case DESTINATION_UNREACHABLE:
+		case BATADV_DESTINATION_UNREACHABLE:
 			printf("From %s: Destination Host Unreachable (icmp_seq %hu)\n", dst_string, ntohs(icmp_packet_in.seqno));
 			break;
-		case TTL_EXCEEDED:
+		case BATADV_TTL_EXCEEDED:
 			printf("From %s: Time to live exceeded (icmp_seq %hu)\n", dst_string, ntohs(icmp_packet_in.seqno));
 			break;
-		case PARAMETER_PROBLEM:
-			printf("Error - the batman adv kernel module version (%d) differs from ours (%d)\n",
-					icmp_packet_in.header.version, COMPAT_VERSION);
+		case BATADV_PARAMETER_PROBLEM:
+			fprintf(stderr, "Error - the batman adv kernel module version (%d) differs from ours (%d)\n",
+					icmp_packet_in.header.version, BATADV_COMPAT_VERSION);
 			printf("Please make sure to use compatible versions!\n");
 			goto out;
 		default:
